<a name="0.4"></a>
# [0.4 WIP](https://github.com/jd-boyd/corker/compare/ver_0.3...master) (2015-08-xx)

* Python 3.3+ support is complete.
* Add tox testing to easy local cross version testing.
* Improve README documentation.
* In exposed methods (decorated with @route), the second argument (after
  `self`) is now the request object.  This breaks compatiblity with
  version 0.3.

<a name="0.3"></a>
# [0.3](https://github.com/jd-boyd/corker/compare/ver_0.2...ver_0.3) (2014-01-20)

* Tidy setup packaging.
* Start automated testing on TravisCI
* Start to ready Python3 support.

<a name="0.2"></a>
# [0.2](https://github.com/jd-boyd/corker/compare/ede27dd4c3d004d7eeda19d40507f2d8dd650964...ver_0.2) (2014-01-20)


* First version released.
